import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.ModelAndView;

public class ApiInterceptor implements HandlerInterceptor {

    private final JwtUserDetailsService jwtUserDetailsService;

    public ApiInterceptor(JwtUserDetailsService jwtUserDetailsService) {
        this.jwtUserDetailsService = jwtUserDetailsService;
    }

    @Override
    public boolean preIntercept(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        // 获取请求路径，判断是否是以/api开头
        String requestUri = request.getRequestURI();
        if (requestUri.startsWith("/api")) {
            // 在这里编写验证手机号和验证码的逻辑，比如从请求参数或者请求头中获取相关信息进行验证
            // 假设从请求参数中获取手机号和验证码，示例代码如下（实际情况可能需要根据具体业务从合适的地方获取）
            String phone = request.getParameter("phone");
            String verificationCode = request.getParameter("verificationCode");
            if (isPhoneValid(phone) && isVerificationCodeValid(verificationCode)) {
                // 根据验证通过的手机号等信息获取对应的用户详情（这里假设你的用户详情是通过JwtUserDetailsService来获取，实际可能需要根据具体业务调整）
                UserDetails userDetails = jwtUserDetailsService.loadUserByUsername(phone);
                // 创建认证对象，将用户详情放入其中，这里假设认证方式是基于用户名密码形式（可根据实际调整）
                Authentication authentication = new UsernamePasswordAuthenticationToken(userDetails, null, userDetails.getAuthorities());
                // 将认证对象放入SecurityContextHolder中，模拟用户已认证的状态
                SecurityContextHolder.getContext().setAuthentication(authentication);
                return true; // 验证通过，放行请求
            } else {
                response.setStatus(HttpServletResponse.SC_UNAUTHORIZED); // 设置未授权状态码
                return false; // 验证不通过，拦截请求
            }
        }
        return true; // 如果不是/api开头的请求，直接放行
    }

    private boolean isPhoneValid(String phone) {
        // 这里编写手机号验证的具体逻辑，比如正则表达式验证手机号格式是否正确等
        return true; // 示例先返回true，实际需完善逻辑
    }

    private boolean isVerificationCodeValid(String verificationCode) {
        // 这里编写验证码验证的具体逻辑，比如和后台存储的验证码进行比对等
        return true; // 示例先返回true，实际需完善逻辑
    }

    @Override
    public void postHandle(HttpServletRequest request, HttpServletResponse response, Object handler, ModelAndView modelAndView) throws Exception {
        HandlerInterceptor.super.postHandle(request, response, handler, modelAndView);
    }

    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler, Exception ex) throws Exception {
        HandlerInterceptor.super.afterCompletion(request, response, handler, ex);
    }
}